# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class FormSubmitResponseTypeEnum(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    REDIRECT = 'redirect'
    NONE = 'none'

    @classmethod
    def from_json(cls, json_str: str) -> FormSubmitResponseTypeEnum:
        """Create an instance of FormSubmitResponseTypeEnum from a JSON string"""
        return FormSubmitResponseTypeEnum(json.loads(json_str))





# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from landing_page_server_connector.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.IsolatedAsyncioTestCase):
    """DefaultApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = DefaultApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_funnels_add_v1_funnels_post(self) -> None:
        """Test case for funnels_add_v1_funnels_post

        Funnels Add  # noqa: E501
        """
        pass

    async def test_funnels_assign_landings_v1_funnels_funnel_id_landings_post(self) -> None:
        """Test case for funnels_assign_landings_v1_funnels_funnel_id_landings_post

        Funnels Assign Landings  # noqa: E501
        """
        pass

    async def test_funnels_count_v1_funnels_count_get(self) -> None:
        """Test case for funnels_count_v1_funnels_count_get

        Funnels Count  # noqa: E501
        """
        pass

    async def test_funnels_delete_v1_funnels_funnel_id_delete(self) -> None:
        """Test case for funnels_delete_v1_funnels_funnel_id_delete

        Funnels Delete  # noqa: E501
        """
        pass

    async def test_funnels_get_v1_funnels_funnel_id_get(self) -> None:
        """Test case for funnels_get_v1_funnels_funnel_id_get

        Funnels Get  # noqa: E501
        """
        pass

    async def test_funnels_group_patch_v1_funnels_patch(self) -> None:
        """Test case for funnels_group_patch_v1_funnels_patch

        Funnels Group Patch  # noqa: E501
        """
        pass

    async def test_funnels_list_v1_funnels_get(self) -> None:
        """Test case for funnels_list_v1_funnels_get

        Funnels List  # noqa: E501
        """
        pass

    async def test_funnels_patch_v1_funnels_funnel_id_patch(self) -> None:
        """Test case for funnels_patch_v1_funnels_funnel_id_patch

        Funnels Patch  # noqa: E501
        """
        pass

    async def test_get_script_categories_v1_scripts_category_get(self) -> None:
        """Test case for get_script_categories_v1_scripts_category_get

        Get Script Categories  # noqa: E501
        """
        pass

    async def test_get_script_placements_v1_scripts_placement_get(self) -> None:
        """Test case for get_script_placements_v1_scripts_placement_get

        Get Script Placements  # noqa: E501
        """
        pass

    async def test_health_check_get(self) -> None:
        """Test case for health_check_get

        Health Check  # noqa: E501
        """
        pass

    async def test_import_tss_template_v1_admin_templates_tss_setup_post(self) -> None:
        """Test case for import_tss_template_v1_admin_templates_tss_setup_post

        Import Tss Template  # noqa: E501
        """
        pass

    async def test_landing_form_add_v1_landings_landing_id_forms_post(self) -> None:
        """Test case for landing_form_add_v1_landings_landing_id_forms_post

        Landing Form Add  # noqa: E501
        """
        pass

    async def test_landing_form_count_v1_landings_landing_id_forms_count_get(self) -> None:
        """Test case for landing_form_count_v1_landings_landing_id_forms_count_get

        Landing Form Count  # noqa: E501
        """
        pass

    async def test_landing_form_delete_all_v1_landings_landing_id_forms_delete(self) -> None:
        """Test case for landing_form_delete_all_v1_landings_landing_id_forms_delete

        Landing Form Delete All  # noqa: E501
        """
        pass

    async def test_landing_form_delete_v1_landings_landing_id_forms_form_id_delete(self) -> None:
        """Test case for landing_form_delete_v1_landings_landing_id_forms_form_id_delete

        Landing Form Delete  # noqa: E501
        """
        pass

    async def test_landing_form_get_v1_landings_landing_id_forms_form_id_get(self) -> None:
        """Test case for landing_form_get_v1_landings_landing_id_forms_form_id_get

        Landing Form Get  # noqa: E501
        """
        pass

    async def test_landing_form_recover_v1_landings_landing_id_forms_form_id_recover_post(self) -> None:
        """Test case for landing_form_recover_v1_landings_landing_id_forms_form_id_recover_post

        Landing Form Recover  # noqa: E501
        """
        pass

    async def test_landing_form_update_v1_landings_landing_id_forms_form_id_post(self) -> None:
        """Test case for landing_form_update_v1_landings_landing_id_forms_form_id_post

        Landing Form Update  # noqa: E501
        """
        pass

    async def test_landing_forms_list_v1_landings_landing_id_forms_get(self) -> None:
        """Test case for landing_forms_list_v1_landings_landing_id_forms_get

        Landing Forms List  # noqa: E501
        """
        pass

    async def test_landing_forms_patch_all_v1_landings_landing_id_forms_patch(self) -> None:
        """Test case for landing_forms_patch_all_v1_landings_landing_id_forms_patch

        Landing Forms Patch All  # noqa: E501
        """
        pass

    async def test_landing_forms_patch_v1_landings_landing_id_forms_form_id_patch(self) -> None:
        """Test case for landing_forms_patch_v1_landings_landing_id_forms_form_id_patch

        Landing Forms Patch  # noqa: E501
        """
        pass

    async def test_landing_history_count_v1_landings_landing_id_history_count_get(self) -> None:
        """Test case for landing_history_count_v1_landings_landing_id_history_count_get

        Landing History Count  # noqa: E501
        """
        pass

    async def test_landing_history_get_v1_landings_landing_id_history_history_id_get(self) -> None:
        """Test case for landing_history_get_v1_landings_landing_id_history_history_id_get

        Landing History Get  # noqa: E501
        """
        pass

    async def test_landing_history_list_v1_landings_landing_id_history_get(self) -> None:
        """Test case for landing_history_list_v1_landings_landing_id_history_get

        Landing History List  # noqa: E501
        """
        pass

    async def test_landings_add_v1_landings_post(self) -> None:
        """Test case for landings_add_v1_landings_post

        Landings Add  # noqa: E501
        """
        pass

    async def test_landings_count_v1_landings_count_get(self) -> None:
        """Test case for landings_count_v1_landings_count_get

        Landings Count  # noqa: E501
        """
        pass

    async def test_landings_delete_v1_landings_landing_id_delete(self) -> None:
        """Test case for landings_delete_v1_landings_landing_id_delete

        Landings Delete  # noqa: E501
        """
        pass

    async def test_landings_duplicate_v1_landings_landing_id_duplicate_post(self) -> None:
        """Test case for landings_duplicate_v1_landings_landing_id_duplicate_post

        Landings Duplicate  # noqa: E501
        """
        pass

    async def test_landings_get_v1_landings_landing_id_get(self) -> None:
        """Test case for landings_get_v1_landings_landing_id_get

        Landings Get  # noqa: E501
        """
        pass

    async def test_landings_group_patch_v1_landings_patch(self) -> None:
        """Test case for landings_group_patch_v1_landings_patch

        Landings Group Patch  # noqa: E501
        """
        pass

    async def test_landings_group_publish_v1_landings_publish_post(self) -> None:
        """Test case for landings_group_publish_v1_landings_publish_post

        Landings Group Publish  # noqa: E501
        """
        pass

    async def test_landings_group_republish_v1_landings_republish_post(self) -> None:
        """Test case for landings_group_republish_v1_landings_republish_post

        Landings Group Republish  # noqa: E501
        """
        pass

    async def test_landings_list_v1_landings_get(self) -> None:
        """Test case for landings_list_v1_landings_get

        Landings List  # noqa: E501
        """
        pass

    async def test_landings_patch_v1_landings_landing_id_patch(self) -> None:
        """Test case for landings_patch_v1_landings_landing_id_patch

        Landings Patch  # noqa: E501
        """
        pass

    async def test_landings_preview_set_v1_landings_landing_id_preview_put(self) -> None:
        """Test case for landings_preview_set_v1_landings_landing_id_preview_put

        Landings Preview Set  # noqa: E501
        """
        pass

    async def test_landings_publish_v1_landings_landing_id_publish_post(self) -> None:
        """Test case for landings_publish_v1_landings_landing_id_publish_post

        Landings Publish  # noqa: E501
        """
        pass

    async def test_landings_recover_v1_landings_landing_id_recover_post(self) -> None:
        """Test case for landings_recover_v1_landings_landing_id_recover_post

        Landings Recover  # noqa: E501
        """
        pass

    async def test_landings_unpublish_v1_landings_landing_id_unpublish_post(self) -> None:
        """Test case for landings_unpublish_v1_landings_landing_id_unpublish_post

        Landings Unpublish  # noqa: E501
        """
        pass

    async def test_landings_update_v1_landings_landing_id_post(self) -> None:
        """Test case for landings_update_v1_landings_landing_id_post

        Landings Update  # noqa: E501
        """
        pass

    async def test_links_redirect_v1_links_landing_uuid_get(self) -> None:
        """Test case for links_redirect_v1_links_landing_uuid_get

        Links Redirect  # noqa: E501
        """
        pass

    async def test_parse_script_v1_scripts_parse_post(self) -> None:
        """Test case for parse_script_v1_scripts_parse_post

        Parse Script  # noqa: E501
        """
        pass

    async def test_portal_clear_homepage_v1_portal_homepage_delete(self) -> None:
        """Test case for portal_clear_homepage_v1_portal_homepage_delete

        Portal Clear Homepage  # noqa: E501
        """
        pass

    async def test_portal_get_homepage_v1_portal_homepage_get(self) -> None:
        """Test case for portal_get_homepage_v1_portal_homepage_get

        Portal Get Homepage  # noqa: E501
        """
        pass

    async def test_portal_set_homepage_v1_portal_homepage_put(self) -> None:
        """Test case for portal_set_homepage_v1_portal_homepage_put

        Portal Set Homepage  # noqa: E501
        """
        pass

    async def test_submit_form_v1_forms_submit_post(self) -> None:
        """Test case for submit_form_v1_forms_submit_post

        Submit Form  # noqa: E501
        """
        pass

    async def test_templates_add_v1_admin_templates_post(self) -> None:
        """Test case for templates_add_v1_admin_templates_post

        Templates Add  # noqa: E501
        """
        pass

    async def test_templates_count_v1_admin_templates_count_get(self) -> None:
        """Test case for templates_count_v1_admin_templates_count_get

        Templates Count  # noqa: E501
        """
        pass

    async def test_templates_delete_v1_admin_templates_template_id_delete(self) -> None:
        """Test case for templates_delete_v1_admin_templates_template_id_delete

        Templates Delete  # noqa: E501
        """
        pass

    async def test_templates_duplicate_v1_admin_templates_template_id_duplicate_post(self) -> None:
        """Test case for templates_duplicate_v1_admin_templates_template_id_duplicate_post

        Templates Duplicate  # noqa: E501
        """
        pass

    async def test_templates_get_v1_admin_templates_template_id_get(self) -> None:
        """Test case for templates_get_v1_admin_templates_template_id_get

        Templates Get  # noqa: E501
        """
        pass

    async def test_templates_group_patch_v1_admin_templates_patch(self) -> None:
        """Test case for templates_group_patch_v1_admin_templates_patch

        Templates Group Patch  # noqa: E501
        """
        pass

    async def test_templates_list_v1_admin_templates_get(self) -> None:
        """Test case for templates_list_v1_admin_templates_get

        Templates List  # noqa: E501
        """
        pass

    async def test_templates_patch_v1_admin_templates_template_id_patch(self) -> None:
        """Test case for templates_patch_v1_admin_templates_template_id_patch

        Templates Patch  # noqa: E501
        """
        pass

    async def test_templates_preview_set_v1_admin_templates_template_id_preview_put(self) -> None:
        """Test case for templates_preview_set_v1_admin_templates_template_id_preview_put

        Templates Preview Set  # noqa: E501
        """
        pass

    async def test_templates_public_count_v1_public_templates_count_get(self) -> None:
        """Test case for templates_public_count_v1_public_templates_count_get

        Templates Public Count  # noqa: E501
        """
        pass

    async def test_templates_public_get_v1_public_templates_template_id_get(self) -> None:
        """Test case for templates_public_get_v1_public_templates_template_id_get

        Templates Public Get  # noqa: E501
        """
        pass

    async def test_templates_public_import_v1_public_templates_template_id_import_post(self) -> None:
        """Test case for templates_public_import_v1_public_templates_template_id_import_post

        Templates Public Import  # noqa: E501
        """
        pass

    async def test_templates_public_list_v1_public_templates_get(self) -> None:
        """Test case for templates_public_list_v1_public_templates_get

        Templates Public List  # noqa: E501
        """
        pass

    async def test_templates_publish_v1_admin_templates_template_id_publish_post(self) -> None:
        """Test case for templates_publish_v1_admin_templates_template_id_publish_post

        Templates Publish  # noqa: E501
        """
        pass

    async def test_templates_recover_v1_admin_templates_template_id_recover_post(self) -> None:
        """Test case for templates_recover_v1_admin_templates_template_id_recover_post

        Templates Recover  # noqa: E501
        """
        pass

    async def test_templates_unpublish_v1_admin_templates_template_id_unpublish_post(self) -> None:
        """Test case for templates_unpublish_v1_admin_templates_template_id_unpublish_post

        Templates Unpublish  # noqa: E501
        """
        pass

    async def test_templates_update_v1_admin_templates_template_id_post(self) -> None:
        """Test case for templates_update_v1_admin_templates_template_id_post

        Templates Update  # noqa: E501
        """
        pass

    async def test_validate_form_v1_forms_validate_post(self) -> None:
        """Test case for validate_form_v1_forms_validate_post

        Validate Form  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
